@@ -63,7 +63,7 @@ class MainImage():
         else:
             add_watermark_service.add_mark2file(file, mark, out, color, size, opacity, space, angle)
 
-    def get_access_token(self):
+    def get_access_token(self, client_api, client_secret):
 
         # 获取token的API
         url = 'https://aip.baidubce.com/oauth/2.0/token'
@@ -72,9 +72,9 @@ class MainImage():
             # 固定参数
             'grant_type': 'client_credentials',
             # 必选参数，传入你的API Key
-            'client_id': 'OVALewIvPyLmiNITnceIhrYf',
+            'client_id': client_api,
             # 必选参数，传入你的Secret Key
-            'client_secret': 'rpBQH8WuXP4ldRQo5tbDkv3t0VgzwvCN'
+            'client_secret': client_secret
         }
         # 发送请求，获取响应数据
 
@@ -84,7 +84,14 @@ class MainImage():
         # 将access_token返回
         return access_token
 
-    def img2Cartoon(self, path):
+    def img2Cartoon(self, path, client_api, client_secret):
+        print('=' * 30)
+        print('正在进行动漫头像的转换')
+        print('本仓库的视频教程：http://t.cn/A6aAvu47')
+        print('这个接口调用的是百度AI平台的免费试用接口（200次），如果代码报错，大概率是试用次数没有了')
+        print('获取免费使用次数的教程，我整理在这个文档里了：https://python-office.com/office/image.html')
+        print('=' * 30)
+
         # 头像动漫化的API
         url = 'https://aip.baidubce.com/rest/2.0/image-process/v1/selfie_anime'
         # 以二进制的方式读取原始图片
@@ -98,7 +105,7 @@ class MainImage():
         # 请求的参数
         params = {
             # 开始获取的access_token
-            'access_token': self.get_access_token(),
+            'access_token': self.get_access_token(client_api, client_secret),
             # 图片的base64编码
             'image': path,
         }
@@ -115,3 +122,5 @@ class MainImage():
             # 将头像写入文件当中
             f.write(anime)
             f.close()
+        print('*' * 20 + "{}".format('动漫头像名称：result.jpg') + '*' * 20)
+        print('*' * 20 + "{}".format('您的动漫头像转换完毕，请在本代码运行的文档里查看') + '*' * 20)
